import wia
import unittest2
import time
from datetime import datetime
import os

class FunctionsTest(unittest2.TestCase):
    timeout = 100000000
    function_id = None

    def test_functions_create(self):
        temp_sk = wia.secret_key
        wia.secret_key = wia.device_secret_key
        def test_function(argument):
            print(argument)
        function_return = wia.Function.create(name='test_function_create', function=test_function)
        self.__class__.test_id = function_return['id']
        wia.secret_key = temp_sk

    def test_functions_delete(self):
        temp_sk = wia.secret_key
        wia.secret_key = wia.device_secret_key
        delete_return = wia.Function.delete(self.__class__.test_id)
        self.assertTrue(delete_return)
        wia.secret_key = temp_sk

    def test_functions_call(self):
        temp_sk = wia.secret_key
        wia.secret_key = wia.device_secret_key
        def test_function_2(payload):
            print("IN TEST FUNCTION 2")
            print(payload)
        wia.Stream.connect()
        count = 0
        while count < self.timeout:
            count += 1
            if wia.Stream.connected:
                break
        if not wia.Stream.connected:
            raise Exception("Unable to connect")
        function_return = wia.Function.create(name='test_function_2', function=test_function_2)
        wia.secret_key = temp_sk
        wia.Function.call(device=wia.device_id, func=function_return['id'], data={'arg1': 'Hello World!', 'arg2': 1000})
        time.sleep(5)
        wia.Stream.disconnect()
        count = 0
        while count < self.timeout:
            count += 1
            if not wia.Stream.connected:
                break
        if wia.Stream.connected:
            raise Exception("Unable to disconnect")
        wia.Function.call(device=wia.device_id, func=function_return['id'], data='Hello World!')

    def test_functions_list(self):
        list_return = wia.Function.list(device=wia.device_id, limit=10, page=0)
        self.assertTrue(list_return['functions'])
        self.assertTrue(type(list_return['functions']) == list)
        self.assertTrue(list_return['count'])
        self.assertTrue(type(list_return['count']) == int)


if __name__ == '__main__':
    unittest2.main()



import os
import unittest2

def all():
    path = os.path.dirname(os.path.realpath(__file__))
    return unittest2.defaultTestLoader.discover(path)

def resources():
    path = os.path.dirname(os.path.realpath(__file__))
    return unittest2.defaultTestLoader.discover(
        os.path.join(path, "resources"))



import wia
import unittest2
import time
import os

def on_connect():
    print("on_connect called in test")

class StreamTest(unittest2.TestCase):

    @classmethod
    def setUpClass(cls):
        wia.secret_key = 'u_sk_0kl0z2W45SEs1SWk7Bu0hDxe'

    # 
    # def test_stream_connect(self):
    #     # wia.Stream.client.on_connect = on_connect
    #     wia.Stream.connect()

if __name__ == '__main__':
    unittest2.main()



import wia
import unittest2
import time
from datetime import datetime
import os

class LogsTest(unittest2.TestCase):
    timeout = 100000000
    mailbox = {}

    def test_logs_publish(self):
        temp_sk = wia.secret_key
        wia.secret_key = wia.device_secret_key
        wia.Stream.connect()
        count = 0
        while count < self.timeout:
            count += 1
            if wia.Stream.connected:
                break
        if not wia.Stream.connected:
            raise Exception("Unable to connect")
        publish_return = wia.Log.publish(level='info', message='test')
        self.assertTrue(publish_return['id'])
        wia.Stream.disconnect()
        count = 0
        while count < self.timeout:
            count += 1
            if not wia.Stream.connected:
                break
        if wia.Stream.connected:
            raise Exception("Unable to disconnect")
        wia.secret_key = temp_sk

    def test_logs_list(self):
        list_return = wia.Log.list(device=wia.device_id, limit=10, page=0)
        self.assertTrue(list_return['logs'])
        self.assertTrue(type(list_return['logs']) == list)
        self.assertTrue(list_return['count'])
        self.assertTrue(type(list_return['count']) == int)

    def test_logs_list_order_sort(self):
        list_return = wia.Log.list(device=wia.device_id, limit=10, page=0, order='timestamp', sort='desc')
        timestamp_list = []
        for log in list_return['logs']:
            timestamp_list.append(log['timestamp'])
        descending = timestamp_list[:]
        descending.sort(reverse=True)
        self.assertEqual(descending, timestamp_list)
        list_return = wia.Log.list(device=wia.device_id, limit=10, page=0, order='timestamp', sort='asc')
        timestamp_list = []
        for log in list_return['logs']:
            timestamp_list.append(log['timestamp'])
        ascending = timestamp_list[:]
        ascending.sort()
        self.assertEqual(ascending, timestamp_list)

    def test_logs_subscribe(self):
        self.__class__.mailbox = {}
        def logs_subscription_func(payload):
            self.__class__.mailbox = payload
        wia.Stream.connect()
        count = 0
        while count < self.timeout:
            count += 1
            if wia.Stream.connected:
                break
        if not wia.Stream.connected:
            raise Exception("Unable to connect")
        wia.Log.subscribe(device=wia.device_id, func=logs_subscription_func)
        count = 0
        while count < self.timeout:
            count += 1
            if wia.Stream.subscribed:
                break
        if not wia.Stream.subscribed:
            raise Exception("Unable to subscribe")
        temp_sk = wia.secret_key
        wia.secret_key = wia.device_secret_key
        wia.Log.publish(level='info', message='test')
        wia.secret_key = temp_sk
        time.sleep(1)
        self.assertEqual(self.__class__.mailbox['message'], 'test')
        self.assertEqual(self.__class__.mailbox['level'], 'info')
        wia.Log.unsubscribe(device=wia.device_id)
        count = 0
        initial_subscribe_count = wia.Stream.subscribed_count
        while count < self.timeout:
            count += 1
            if wia.Stream.subscribed_count < initial_subscribe_count:
                break
        if wia.Stream.subscribed_count == initial_subscribe_count:
            raise Exception("Unable to unsubscribe")


if __name__ == '__main__':
    unittest2.main()



import wia
import unittest2
import time
import os

class SensorsTest(unittest2.TestCase):
    timeout = 100000000
    mailbox = {}

    def test_sensors_publish(self):
        wia.secret_key = wia.device_secret_key
        wia.Stream.connect()
        count = 0
        while count < self.timeout:
            count += 1
            if wia.Stream.connected:
                break
        if not wia.Stream.connected:
            raise Exception("Unable to connect")
        publish_return = wia.Sensor.publish(name='test_sensor_1', data=99)
        self.assertTrue(publish_return['id'])
        wia.Stream.disconnect()
        count = 0
        while count < self.timeout:
            count += 1
            if not wia.Stream.connected:
                break
        if wia.Stream.connected:
            raise Exception("Unable to disconnect")

    def test_sensors_list(self):
        list_return = wia.Sensor.list(device=wia.device_id, limit=10, page=0)
        self.__class__.sensor_count = list_return['count']
        self.assertTrue(list_return['sensors'])
        self.assertTrue(type(list_return['sensors']) == list)
        self.assertTrue(list_return['count'])
        self.assertTrue(type(list_return['count']) == int)

    def test_sensors_list_order_sort(self):
        list_return = wia.Sensor.list(device=wia.device_id, limit=10, page=0, order='timestamp', sort='desc')
        timestamp_list = []
        for sensor in list_return['sensors']:
            timestamp_list.append(sensor['timestamp'])
        descending = timestamp_list[:]
        descending.sort(reverse=True)
        self.assertEqual(descending, timestamp_list)
        list_return = wia.Sensor.list(device=wia.device_id, limit=10, page=0, order='timestamp', sort='asc')
        timestamp_list = []
        for sensor in list_return['sensors']:
            timestamp_list.append(sensor['timestamp'])
        ascending = timestamp_list[:]
        ascending.sort()
        self.assertEqual(ascending, timestamp_list)

    def test_sensors_list_name(self):
        list_return = wia.Sensor.list(device = wia.device_id, name='test_sensor_1')
        for sensor in list_return['sensors']:
            self.assertEqual('test_sensor_1', sensor['name'])

    def test_sensors_list_since_until(self):
        hour_ago = int((time.time())*1000 - 3600000)
        list_return = wia.Sensor.list(device=wia.device_id, order='timestamp', sort='desc', since=hour_ago)
        self.assertTrue(list_return['count'] <= self.__class__.sensor_count)
        list_return = {}
        list_return = wia.Sensor.list(device=wia.device_id, order='timestamp', sort='desc', until=hour_ago)
        self.assertTrue(list_return['count'] <= self.__class__.sensor_count)

    def test_sensors_subscribe(self):
        self.__class__.mailbox = {}
        def wildcard_function(payload):
            pass
        def specific_function(payload):
            self.__class__.mailbox = payload
        wia.Stream.connect()
        count = 0
        while count < self.timeout:
            count += 1
            if wia.Stream.connected:
                break
        if not wia.Stream.connected:
            raise Exception("Unable to connect")
        wia.Sensor.subscribe(device=wia.device_id, func=wildcard_function)
        wia.Sensor.subscribe(device=wia.device_id, func=specific_function, name='subscribe_test_sensor')
        count = 0
        while count < self.timeout:
            count += 1
            if wia.Stream.subscribed:
                break
        if not wia.Stream.subscribed:
            raise Exception("Unable to subscribe")
        temp_sk = wia.secret_key
        wia.secret_key = wia.device_secret_key
        wia.Sensor.publish(name='subscribe_test_sensor', data=99)
        wia.secret_key = temp_sk
        time.sleep(5)
        self.assertEqual(self.__class__.mailbox['name'], 'subscribe_test_sensor')
        self.assertEqual(self.__class__.mailbox['data'], 99)
        wia.Sensor.unsubscribe(device=wia.device_id, name='subscribe_test_sensor')
        wia.Sensor.unsubscribe(device=wia.device_id)
        count = 0
        initial_subscribe_count = wia.Stream.subscribed_count
        while count < self.timeout:
            count += 1
            if wia.Stream.subscribed_count < initial_subscribe_count:
                break
        if wia.Stream.subscribed_count == initial_subscribe_count:
            raise Exception("Unable to unsubscribe")

if __name__ == '__main__':
    unittest2.main()



import wia
import unittest2
import time
import os

class DeviceTest(unittest2.TestCase):
    test_id = ''

    def test_create(self):
        device = wia.Device.create(name='johnDoe',serialNumber='test')
        self.__class__.test_id = device['id']
        self.assertEqual(device['name'], 'johnDoe')

    def test_retrieve(self):
        self.assertEqual(wia.Device.retrieve(self.__class__.test_id).name, 'johnDoe')
        wia.Device.delete(self.__class__.test_id)

    def test_update(self):
        test_device = wia.Device.create(name='johnDoe')
        self.assertEqual(test_device['name'], 'johnDoe')
        test_device['name'] = 'janeDoe'
        self.assertEqual(test_device['name'], 'janeDoe')
        wia.Device.update(test_device['id'], name=test_device['name'])
        self.assertEqual(wia.Device.retrieve(test_device['id']).name, 'janeDoe')
        wia.Device.delete(test_device['id'])

    def test_delete(self):
        test_device = wia.Device.create(name='toBeDestroyed')
        self.assertEqual(wia.Device.delete(test_device['id']), True)

    def test_device_list(self):
        list_return = wia.Device.list(limit=20, page=0)
        self.assertTrue(list_return['devices'])
        self.assertTrue(type(list_return['devices']) == list)
        self.assertTrue(list_return['count'])
        self.assertTrue(type(list_return['count']) == int)
        self.assertTrue(len(list_return['devices']) == 20)

    def test_device_list_order_sort(self):
        list_return = wia.Device.list(order='createdAt', sort='desc')
        timestamp_list = []
        for device in list_return['devices']:
            timestamp_list.append(device['createdAt'])
        descending = timestamp_list[:]
        descending.sort(reverse=True)
        self.assertTrue(descending == timestamp_list)
        list_return = wia.Device.list(order='createdAt', sort= 'asc')
        timestamp_list = []
        for device in list_return['devices']:
            timestamp_list.append(device['createdAt'])
        ascending = timestamp_list[:]
        ascending.sort()
        self.assertTrue(ascending == timestamp_list)


if __name__ == '__main__':
    unittest2.main()



import wia
from wia.rest_client import post, get, put, delete
from wia.util import logger
from wia.stream_client import Stream
import time

unsubscribe_flag = False

class Device(object):
    def __init__(self, **kwargs):
        self.id = (kwargs['id'] if 'id' in kwargs else None)
        self.name = (kwargs['name'] if 'name' in kwargs else None)
        self.events = (kwargs['events'] if 'events' in kwargs else None)
        self.isOnline = (kwargs['isOnline'] if 'isOnline' in kwargs else None)
        self.createdAt = (kwargs['createdAt'] if 'createdAt' in kwargs else None)
        self.updatedAt = (kwargs['updatedAt'] if 'updatedAt' in kwargs else None)

    @classmethod
    def create(self, **kwargs):
        path = 'devices'
        created_device = post(path, kwargs)
        return created_device

    @classmethod
    def retrieve(self, id, sk=None):
        path = 'devices/' + id
        if (id == 'me') and sk:
            retrieved_device = get(path, sk=sk)
        elif (id == 'me') and not sk:
            raise SyntaxError('Must provide device secret key if retrieving self')
        else:
            retrieved_device = get(path)
        return Device(**retrieved_device)

    @classmethod
    def update(self, id, **kwargs):
        path = 'devices/' + id
        return put(path, **kwargs)

    @classmethod
    def delete(self, id):
        path = 'devices/' + id
        if delete(path).status_code == 200:
            return True
        else:
            return False

    @classmethod
    def list(self, **kwargs):
        list_devices = get('devices', **kwargs)
        for device in list_devices['devices']:
            data = device
            logger.info("device: %s", data)
        logger.info("count: %s", list_devices['count'])
        return list_devices

class Event(object):
    def __init__(self, **kwargs):
        self.name = (kwargs['name'] if 'name' in kwargs else None)
        self.data = (kwargs['data'] if 'data' in kwargs else None)
        self.timestamp = (kwargs['timestamp'] if 'timestamp' in kwargs else None)

    @classmethod
    def publish(self, **kwargs):
        path = 'events'
        new_event = post(path, kwargs)
        if wia.Stream.connected:
            topic = 'devices/' + wia.device_id + '/' + path + '/' + kwargs['name']
            Stream.publish(topic=topic, **kwargs)
        return new_event

    @classmethod
    def subscribe(self, **kwargs):
        device=kwargs['device']
        topic='devices/' + device + '/events/'
        if 'name' in kwargs:
            topic += kwargs['name']
        else:
            topic += '+'
        Stream.subscribe(topic=topic, func=kwargs['func'])

    @classmethod
    def unsubscribe(self, **kwargs):
        device=kwargs['device']
        topic='devices/' + device + '/events/'
        if 'name' in kwargs:
            topic += kwargs['name']
        else:
            topic += '+'
        Stream.unsubscribe(topic=topic)

    @classmethod
    def list(self, **kwargs):
        list_events = get('events', **kwargs)
        for event in list_events['events']:
            data = event
            logger.info("event: %s", data)
        logger.info("count: %s", list_events['count'])
        return list_events

class Sensor(object):
    def __init__(self, **kwargs):
        self.name = (kwargs['name'] if 'name' in kwargs else None)
        self.data = (kwargs['data'] if 'data' in kwargs else None)
        self.timestamp = (kwargs['timestamp'] if 'timestamp' in kwargs else None)

    @classmethod
    def publish(self, **kwargs):
        path = 'sensors'
        new_sensor = post(path, kwargs)
        if wia.Stream.connected:
            topic = 'devices/' + wia.device_id + '/' + path + '/' + kwargs['name']
            Stream.publish(topic=topic, **kwargs)
        return new_sensor

    @classmethod
    def subscribe(self, **kwargs):
        device=kwargs['device']
        topic='devices/' + device + '/sensors/'
        if 'name' in kwargs:
            topic += kwargs['name']
        else:
            topic += '+'
        Stream.subscribe(topic=topic, func=kwargs['func'])

    @classmethod
    def unsubscribe(self, **kwargs):
        device=kwargs['device']
        topic='devices/' + device + '/sensors/'
        if 'name' in kwargs:
            topic += kwargs['name']
        else:
            topic += '+'
        Stream.unsubscribe(topic=topic)

    @classmethod
    def list(self, **kwargs):
        list_sensors = get('sensors', **kwargs)
        for sensor in list_sensors['sensors']:
            data = sensor
            logger.info("sensor: %s", data)
        logger.info("count: %s", list_sensors['count'])
        return list_sensors

class Location(object):
    def __init__(self, **kwargs):
        self.id = (kwargs['id'] if 'id' in kwargs else None)
        self.latitude = (kwargs['latitude'] if 'latitude' in kwargs else None)
        self.longitude = (kwargs['longitude'] if 'longitude' in kwargs else None)
        self.altitude = (kwargs['altitude'] if 'altitude' in kwargs else None)
        self.timestamp = (kwargs['timestamp'] if 'timestamp' in kwargs else None)
        self.recievedTimestamp = (kwargs['recievedTimestamp'] if 'recievedTimestamp' in kwargs else None)

    @classmethod
    def publish(self, **kwargs):
        path = 'locations'
        new_location = post(path, kwargs)
        if wia.Stream.connected:
            topic = 'devices/' + wia.device_id + '/' + path
            Stream.publish(topic=topic, **kwargs)
        return new_location

    @classmethod
    def subscribe(self, **kwargs):
        device = kwargs['device']
        topic = 'devices/' + device + '/locations'
        Stream.subscribe(topic=topic, func=kwargs['func'])

    @classmethod
    def unsubscribe(self, **kwargs):
        device = kwargs['device']
        topic = 'devices/' + device + '/locations'
        Stream.unsubscribe(topic=topic)

    @classmethod
    def list(self, **kwargs):
        list_locations = get('locations', **kwargs)
        for location in list_locations['locations']:
            data = location
            logger.info("location: %s", data)
        logger.info("count: %s", list_locations['count'])
        return list_locations

class Log(object):
    def __init__(self, **kwargs):
        self.level = (kwargs['level'] if 'level' in kwargs else None)
        self.message = (kwargs['message'] if 'message' in kwargs else None)
        self.data = (kwargs['data'] if 'data' in kwargs else None)
        self.timestamp = (kwargs['timestamp'] if 'timestamp' in kwargs else None)

    @classmethod
    def publish(self, **kwargs):
        path = 'logs'
        new_log = post(path, kwargs)
        if wia.Stream.connected:
            topic = 'devices/' + wia.device_id + '/' + path
            Stream.publish(topic=topic, **kwargs)
        return new_log

    @classmethod
    def subscribe(self, **kwargs):
        device = kwargs['device']
        topic = 'devices/' + device + '/logs'
        Stream.subscribe(topic=topic, func=kwargs['func'])

    @classmethod
    def unsubscribe(self, **kwargs):
        device = kwargs['device']
        topic = 'devices/' + device + '/logs'
        Stream.unsubscribe(topic=topic)

    @classmethod
    def list(self, **kwargs):
        list_logs = get('logs', **kwargs)
        for log in list_logs['logs']:
            data = log
            logger.info("log: %s", data)
        logger.info("count: %s", list_logs['count'])
        return list_logs

class Function(object):
    def __init__(self, **kwargs):
        self.id = (kwargs['id'] if 'id' in kwargs else None)
        self.name = (kwargs['name'] if 'name' in kwargs else None)
        self.isEnabled = (kwargs['isEnabled'] if 'isEnabled' in kwargs else None)
        self.device = (kwargs['device'] if 'device' in kwargs else None)
        self.enabledAt = (kwargs['enabledAt'] if 'enabledAt' in kwargs else None)
        self.createdAt = (kwargs['createdAt'] if 'createdAt' in kwargs else None)
        self.updatedAt = (kwargs['updatedAt'] if 'updatedAt' in kwargs else None)

    @classmethod
    def create(self, **kwargs):
        path = 'functions'
        data = {'name': kwargs['name']}
        new_function = post(path, data)
        device = wia.device_id
        topic = 'devices/' + device + '/functions/' + new_function['id'] + '/call'
        attempts = 0
        while attempts < 6:
            Stream.subscribe(topic=topic, func=kwargs['function'])
            time.sleep(0.5)
            attempts += 1
            if Stream.subscribed == True:
                break
        if not Stream.subscribed:
            raise Exception("SUBSCRIPTION UNSUCCESSFUL")
        return new_function

    @classmethod
    def delete(self, func_id):
        path = 'functions/' + func_id
        if delete(path).status_code == 200:
            return True
        else:
            return False

    @classmethod
    def call(self, **kwargs):
        if wia.Stream.connected:
            topic = 'devices/' + kwargs['device'] + '/functions/' + kwargs['func'] + '/call'
            Stream.publish(topic=topic, **kwargs['data'])
        else:
            path = 'functions/' + kwargs['func'] + '/call'
            data = kwargs['data']
            request_return = post(path, kwargs)

    @classmethod
    def list(self, **kwargs):
        list_functions = get('functions', **kwargs)
        for function in list_functions['functions']:
            data = function
            logger.info("function: %s", data)
        logger.info("count: %s", list_functions['count'])
        return list_functions



from wia.version import VERSION
import os
import logging

logging.basicConfig(level=logging.DEBUG)

__version__ = VERSION

secret_key = os.environ['secret_key']
device_secret_key = os.environ['device_secret_key']
api_version = None
device_id = os.environ['device_id']

rest_api_base = 'https://api.wia.io/v1'
stream_protocol = 'mqtt'
stream_host = 'api.wia.io'
stream_port = 1883

from wia.resource import (
    Device,
    Event,
    Sensor,
    Location,
    Log,
    Function
)

from wia.stream_client import (
    Stream
)

from wia.version import VERSION



import paho.mqtt.client as mqtt
import wia
import threading
import resource
import json
import re
import sys

client = mqtt.Client()
function_subscriptions = {}

class Stream(object):
    connected = False
    subscribed = None
    subscribed_count = 0

    @classmethod
    def connect(self):
        global client
        client.username_pw_set(wia.secret_key, ' ')
        client.on_connect = Stream.on_connect
        client.on_disconnect = Stream.on_disconnect
        client.on_subscribe = Stream.on_subscribe
        client.on_unsubscribe = Stream.on_unsubscribe
        client.on_message = Stream.on_message
        client.connect(wia.stream_host, wia.stream_port, 60)
        client.loop_start()

    @classmethod
    def disconnect(self):
        global client
        client.loop_stop()
        client.disconnect()

    @classmethod
    def publish(self, **kwargs):
        topic = kwargs['topic']
        kwargs.pop('topic')
        client.publish(topic, payload=json.dumps(kwargs), qos=0, retain=False)

    @classmethod
    def subscribe(self, **kwargs):
        function_subscriptions[kwargs['topic']] = kwargs['func']
        def thread_proc():
            client.subscribe(kwargs['topic'], qos=0)
            subscribing_event = threading.Event()
        t = threading.Thread(group=None, target=thread_proc, name=None)
        t.run()

    @classmethod
    def unsubscribe(self, **kwargs):
        function_subscriptions.pop(kwargs['topic'])
        client.unsubscribe(kwargs['topic'])

    @classmethod
    def on_connect(self, client, userdata, flags, rc):
        self.connected = True
        print("Connect success")

    @classmethod
    def on_disconnect(self, client, userdata, rc):
        self.connected = False
        print("Disconnect success")

    @classmethod
    def on_subscribe(self, client, userdata, msg, granted_qos):
        self.subscribed = True
        self.subscribed_count += 1
        print("Subscribe success")

    @classmethod
    def on_message(self, client, userdata, msg):
        topic=re.split('/', msg.topic)
        # 1. Check for specific topic function. If exists, call
        if msg.topic in function_subscriptions:
            payload = json.loads(msg.payload.decode())
            payload = dict([(str(k), v) for k, v in payload.items()])
            for k, v in payload.items():
                if int(sys.version_info[0]) >=3:
                    if isinstance(v, bytes):
                        payload[k] = str(v)
                else:
                    if isinstance(v, unicode):
                        payload[k] = str(v)
            function_subscriptions[msg.topic](payload)
        # 2. Check for wildcard topic function. If exists, call
        wildcard_topic = topic[0] + "/" + topic[1] + "/" + topic[2] + "/+"
        if wildcard_topic in function_subscriptions:
            if hasattr(function_subscriptions[wildcard_topic], '__call__'):
                payload = json.loads(msg.payload.decode())
                payload = dict([(str(k), v) for k, v in payload.items()])
                for k, v in payload.items():
                    if int(sys.version_info[0]) >=3:
                        if isinstance(v, bytes):
                            payload[k] = str(v)
                    else:
                        if isinstance(v, unicode):
                            payload[k] = str(v)
                function_subscriptions[wildcard_topic](payload)

    @classmethod
    def on_unsubscribe(self, client, userdata, mid):
        self.subscribed_count -= 1
        if self.subscribed_count == 0:
            self.subscribed = False
        print("Unsubscribe success")



import requests
import wia

'''
wia_post:
    args:
        path:   string specifying url path
        kwargs: variable-length dict which can
                contain data for post request
'''
def post(path, kwargs, device=None):
    key = 'Bearer ' + wia.secret_key
    url = wia.rest_api_base + '/' + path
    headers = {'Authorization': key}
    data = kwargs
    r = requests.post(url, json=data, headers=headers)
    try:
        r = r.json()
    except ValueError:
        pass
    return r

'''
wia_put:
    args:
        path:   string specifying url path
        kwargs: variable-length dict which can
                contain data for put request
'''
def put(path, **kwargs):
    url = wia.rest_api_base + '/' + path
    key = 'Bearer ' + wia.secret_key
    headers = {'Authorization': key}
    data = kwargs
    r = requests.put(url, json=data, headers=headers)
    return r.json()

'''
wia_get:
    args:
        path:   string specifying url path
        sk: secret_key IFF device is retrieving itself
        kwargs: variable-length dict which can
                contain query params
'''
def get(path=None, **kwargs):
    key = 'Bearer ' + wia.secret_key
    url = wia.rest_api_base + '/' + path
    headers = {'Authorization': key}
    r = requests.get(url, headers=headers, params=kwargs)
    return r.json()
'''
wia_delete:
    args:
        path: string specifying url path
'''
def delete(path):
    url = wia.rest_api_base + '/' + path
    key = 'Bearer ' + wia.secret_key
    headers = {'Authorization': key}
    r = requests.delete(url, headers=headers)
    return r
